import { sendResponse } from './sendResponse';
import { closeConnection } from './closeConnection';
export class WsApi {
    requestHandlers = {
        '$connect': () => Promise.resolve(),
        '$disconnect': () => Promise.resolve(),
    };
    addRouteHandler(route, requestHandler) {
        this.requestHandlers[route.action] = requestHandler;
        return this;
    }
    async handleRequest(event) {
        const { body } = event;
        const { connectionId, domainName, stage, routeKey: action } = event.requestContext;
        if (!action)
            throw 'No routeKey/action';
        if (!connectionId)
            throw 'No connectionId';
        if (!domainName)
            throw 'No domainName';
        if (!body && !['$connect', '$disconnect'].includes(action))
            throw 'No body';
        const requestHandler = this.requestHandlers[action];
        if (!requestHandler)
            throw `No requestHandler found for action ${action}`;
        const endpoint = `https://${domainName}/${stage}`;
        const connection = { endpoint, connectionId };
        await requestHandler(body && JSON.parse(body), {
            connection,
            sendResponse: async (response) => await sendResponse(connection, response),
            closeConnection: async () => await closeConnection(connection),
        });
        return {
            statusCode: 200,
            body: '',
        };
    }
}
//# sourceMappingURL=WsApi.js.map